From 2b0fff52002df8e4dc35c7b50d2ffa9e302b50d7 Mon Sep 17 00:00:00 2001
From: "tender.wang" <tender.wang@openpie.com>
Date: Mon, 8 Apr 2024 18:35:05 +0800
Subject: [PATCH] Fix some grammer errors from error messages and codes
 comments.

---
 src/backend/commands/tablecmds.c      | 18 +++++++++---------
 src/backend/parser/parse_utilcmd.c    |  2 +-
 src/backend/partitioning/partbounds.c |  6 +++---
 src/include/nodes/parsenodes.h        |  2 +-
 4 files changed, 14 insertions(+), 14 deletions(-)

diff --git a/src/backend/commands/tablecmds.c b/src/backend/commands/tablecmds.c
index 582890a302..2b0b594d75 100644
--- a/src/backend/commands/tablecmds.c
+++ b/src/backend/commands/tablecmds.c
@@ -19086,7 +19086,7 @@ QueuePartitionConstraintValidation(List **wqueue, Relation scanrel,
 }
 
 /*
- * attachPartitionTable: attach new partition to partitioned table
+ * attachPartitionTable: attach a new partition to the partitioned table
  *
  * wqueue: the ALTER TABLE work queue; can be NULL when not running as part
  *   of an ALTER TABLE sequence.
@@ -20879,10 +20879,10 @@ GetAttributeStorage(Oid atttypid, const char *storagemode)
  */
 typedef struct SplitPartitionContext
 {
-	ExprState  *partqualstate;	/* expression for check slot for partition
+	ExprState  *partqualstate;	/* expression for checking slot for partition
 								 * (NULL for DEFAULT partition) */
 	BulkInsertState bistate;	/* state of bulk inserts for partition */
-	TupleTableSlot *dstslot;	/* slot for insert row into partition */
+	TupleTableSlot *dstslot;	/* slot for inserting row into partition */
 	Relation	partRel;		/* relation for partition */
 } SplitPartitionContext;
 
@@ -21129,7 +21129,7 @@ moveSplitTableRows(Relation rel, Relation splitRel, List *partlist, List *newPar
 }
 
 /*
- * createPartitionTable: create table for new partition with given name
+ * createPartitionTable: create table for a new partition with given name
  * (newPartName) like table (modelRelName)
  *
  * Emulates command: CREATE TABLE <newPartName> (LIKE <modelRelName>
@@ -21206,7 +21206,7 @@ ATExecSplitPartition(List **wqueue, AlteredTableInfo *tab, Relation rel,
 
 	/*
 	 * We are going to detach and remove this partition: need to use exclusive
-	 * lock for prevent DML-queries to the partition.
+	 * lock for preventing DML-queries to the partition.
 	 */
 	splitRel = table_openrv(cmd->name, AccessExclusiveLock);
 
@@ -21256,13 +21256,13 @@ ATExecSplitPartition(List **wqueue, AlteredTableInfo *tab, Relation rel,
 
 	/*
 	 * If new partition has the same name as split partition then we should
-	 * rename split partition for reuse name.
+	 * rename split partition for reusing name.
 	 */
 	if (isSameName)
 	{
 		/*
 		 * We must bump the command counter to make the split partition tuple
-		 * visible for rename.
+		 * visible for renaming.
 		 */
 		CommandCounterIncrement();
 		/* Rename partition. */
@@ -21271,7 +21271,7 @@ ATExecSplitPartition(List **wqueue, AlteredTableInfo *tab, Relation rel,
 
 		/*
 		 * We must bump the command counter to make the split partition tuple
-		 * visible after rename.
+		 * visible after renaming.
 		 */
 		CommandCounterIncrement();
 	}
@@ -21446,7 +21446,7 @@ ATExecMergePartitions(List **wqueue, AlteredTableInfo *tab, Relation rel,
 
 		/*
 		 * We are going to detach and remove this partition: need to use
-		 * exclusive lock for prevent DML-queries to the partition.
+		 * exclusive lock for preventing DML-queries to the partition.
 		 */
 		mergingPartition = table_openrv(name, AccessExclusiveLock);
 
diff --git a/src/backend/parser/parse_utilcmd.c b/src/backend/parser/parse_utilcmd.c
index 88a4a41186..9e3e14087f 100644
--- a/src/backend/parser/parse_utilcmd.c
+++ b/src/backend/parser/parse_utilcmd.c
@@ -3804,7 +3804,7 @@ transformAlterTableStmt(Oid relid, AlterTableStmt *stmt,
 					if (list_length(partcmd->partlist) < 2)
 						ereport(ERROR,
 								(errcode(ERRCODE_INVALID_OBJECT_DEFINITION),
-								 errmsg("list of new partitions should contains at least two items")));
+								 errmsg("list of new partitions should contain at least two items")));
 
 					if (cmd->subtype == AT_SplitPartition)
 						transformPartitionCmdForSplit(&cxt, partcmd);
diff --git a/src/include/nodes/parsenodes.h b/src/include/nodes/parsenodes.h
index 01fa1a6c2e..32df680a9a 100644
--- a/src/include/nodes/parsenodes.h
+++ b/src/include/nodes/parsenodes.h
@@ -956,7 +956,7 @@ typedef struct PartitionCmd
 	NodeTag		type;
 	RangeVar   *name;			/* name of partition to attach/detach */
 	PartitionBoundSpec *bound;	/* FOR VALUES, if attaching */
-	List	   *partlist;		/* list of partitions, for SPLIT PARTITION
+	List	   *partlist;		/* list of partitions, for MERGE/SPLIT PARTITION
 								 * command */
 	bool		concurrent;
 } PartitionCmd;
diff --git a/src/backend/partitioning/partbounds.c b/src/backend/partitioning/partbounds.c
index c36e26ba4b..83df89e9b1 100644
--- a/src/backend/partitioning/partbounds.c
+++ b/src/backend/partitioning/partbounds.c
@@ -4986,7 +4986,7 @@ satisfies_hash_partition(PG_FUNCTION_ARGS)
  * This is a helper function for check_partitions_for_split() and
  * calculate_partition_bound_for_merge().
  * This function compares upper bound of first_bound and lower bound of
  * second_bound. These bounds should be equals except case
  * "defaultPart == true" (this means that one of split partitions is DEFAULT).
  * In this case upper bound of first_bound can be less than lower bound of
  * second_bound because space between of these bounds will be included in
@@ -5262,7 +5262,7 @@ check_partition_bounds_for_split_range(Relation parent,
 					 errmsg("%s bound of partition \"%s\" is %s %s bound of split partition",
 							first ? "lower" : "upper",
 							relname,
-							defaultPart ? (first ? "less than" : "greater than") : "not equals to",
+							defaultPart ? (first ? "less than" : "greater than") : "not equal to",
 							first ? "lower" : "upper"),
 					 parser_errposition(pstate, datum->location)));
 		}
@@ -5483,7 +5483,7 @@ check_parent_values_in_new_partitions(Relation parent,
 		Const	   *notFoundVal;
 
 		if (!searchNull)
-			/* Make Const for get string representation of not found value. */
+			/* Make Const for getting string representation of not found value. */
 			notFoundVal = makeConst(key->parttypid[0],
 									key->parttypmod[0],
 									key->parttypcoll[0],
@@ -4986,7 +4986,7 @@ satisfies_hash_partition(PG_FUNCTION_ARGS)
  * calculate_partition_bound_for_merge().
  * This function compares upper bound of first_bound and lower bound of
- * second_bound. These bounds should be equals except case
+ * second_bound. These bounds should be equal except case
  * "defaultPart == true" (this means that one of split partitions is DEFAULT).
  * In this case upper bound of first_bound can be less than lower bound of
-- 
2.25.1

